==> plotsettings-1.0.2-py2-none-any.whl: plotsettings/test/custom_journals.py <==
'''
Dictionary of plot settings for submission to the `Journal of
Irreproducible Results <http://www.jir.com/favorites.html>`_

Created on Oct 10, 2014

@author: gdelraye
'''

# Journals in alphabetical order:
journals = {
#--- Journal of Irreproducible Results, updated 14OCT2014:
            'Journal of Irreproducible Results':   {'rcParams':    {'backend': 'pdf',
                                                                    'axes.labelsize': 9,
                                                                    'text.fontsize': 9,
                                                                    'xtick.labelsize': 9,
                                                                    'ytick.labelsize': 9,
                                                                    'legend.pad': 0.1,
                                                                    'legend.fontsize': 9,
                                                                    'lines.markersize': 3,
                                                                    'font.size': 9,
                                                                    'font.family': u'sans-serif',
                                                                    'font.sans-serif': ['Comic Sans'],
                                                                    'text.usetex': False},
                                                    'figsize':     {'column_width': 85,
                                                                    'gutter_width': 4,
                                                                    'units': 'mm'},
                                                    'panel_labels':{'fontweight': 'bold',
                                                                    'case': 'upper',
                                                                    'prefix': '',
                                                                    'suffix': ':'}
                                                    },
            }

==> plotsettings-1.0.4_1-py2-none-any.whl: plotsettings/test/custom_journals.py <==
'''
Dictionary of plot settings for submission to the `Journal of
Irreproducible Results <http://www.jir.com/favorites.html>`_

Created on Oct 10, 2014

@author: gdelraye
'''

# Journals in alphabetical order:
journals = {
#--- Journal of Irreproducible Results, updated 14OCT2014:
            'Journal of Irreproducible Results':   {'rcParams':    {'backend': 'pdf',
                                                                    'axes.labelsize': 9,
                                                                    'text.fontsize': 9,
                                                                    'xtick.labelsize': 9,
                                                                    'ytick.labelsize': 9,
                                                                    'legend.pad': 0.1,
                                                                    'legend.fontsize': 9,
                                                                    'lines.markersize': 3,
                                                                    'font.size': 9,
                                                                    'font.family': u'sans-serif',
                                                                    'font.sans-serif': ['Comic Sans MS'],
                                                                    'text.usetex': False},
                                                    'figsize':     {'column_width': 85,
                                                                    'gutter_width': 4,
                                                                    'units': 'mm'},
                                                    'panel_labels':{'fontweight': 'bold',
                                                                    'case': 'upper',
                                                                    'prefix': '',
                                                                    'suffix': ':'}
                                                    },
            }
